@@ -1,10 +1,12 @@
 from .start_phone_auth import StartPhoneAuth
 from .validate_code import ValidateCode
 from .validate_password import ValidatePassword
+from .sign_out import SignOut
 
 
 __all__ = (
     "StartPhoneAuth",
     "ValidateCode",
     "ValidatePassword",
+    "SignOut"
 )
